# Generated by roxygen2: do not edit by hand

S3method(plot,mdecomp)
S3method(summary,leslie)
export("%>%")
export(LT)
export(MLT)
export(ages)
export(asdt)
export(ccm)
export(decomp)
export(edagger)
export(fert.approx)
export(get_rosbris)
export(gini)
export(hli)
export(leecart)
export(leslie)
export(mac)
export(mdecomp)
export(med.age)
export(mort.approx)
export(plot_pyr)
export(tatfr)
export(tfr)
export(yll)
import(dplyr)
import(forecast)
import(ggplot2)
import(scales)
import(splines)
import(tidyr)
importFrom(magrittr,"%>%")
