
<!-- README.md is generated from README.Rmd. Please edit that file -->

# demor

The goal of `demor` is to provide you with:  
1. the most basic functions for demographic analysis  
2. some data

Now, `demor` provides the ability to download Russian
mortality/fertility data from [Rosbris
(РосБРиС)](http://demogr.nes.ru/index.php/ru/demogr_indicat/data) in a
user-friendly format. It also includes functions for building life
tables, age and cause decompositions, fitting Lee-Carter model,
calculating years of life lost, and more.

### Installation

You can install the development version of `demor` from GitHub with:

``` r
# install.packages("devtools")
devtools::install_github("vadvu/demor")
```

### Tutorial

Examples of how to use `demor` can be found on its
[website](https://vadvu.github.io/demor/) in the [Get
started](https://vadvu.github.io/demor/articles/demor.html) section. The
detailed information about each function can be found in
[this](https://vadvu.github.io/demor/reference/index.html) section of
the website. 

The package is also presented in [this](https://doi.org/10.17323/demreview.v12i4.30415) paper (in Russ.).

### Suggested Citations

If you use the package in your research, please, cite this paper (in Russ.) 
where the package is presented:

**English citation**: Ustyuzhanin V. (2025). demor: R package for basic and advanced methods of demographic analysis. 
Demographic Review, 12(4), 100-122. 
https://doi.org/10.17323/demreview.v12i4.30415

**Russian citation**: Устюжанин В.В. (2025). demor: пакет в R для базовых и продвинутых методов демографического анализа. 
Демографическое обозрение, 12(4), 100-122. 
https://doi.org/10.17323/demreview.v12i4.30415

### Contact Information

If you have any comments on the `demor` (suggestions for development,
bug fixes, etc.), please, feel free to contact me via email:
<vvustiuzhanin@yandex.ru>

### Acknowledgements

This package is developed with support by the Russian Science Foundation (Project No 24-18-00650). 

Этот пакет подготовлен при поддержке Российского научного фонда (проект №24-18-00650).

