if (getRversion() >= "2.15.1") {
  utils::globalVariables(
    c(
      ".",
      "code",
      "fx",
      "fxA",
      "Group",
      "N",
      "parity",
      "Reg",
      "Sex",
      "age",
      "age2",
      "conf.high",
      "conf.low",
      "ex",
      "ex12",
      "group",
      "mx",
      "pop",
      "pop2",
      "sex",
      "territory",
      "Year",
      "year"
    )
  )
}
