% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{asdtex}
\alias{asdtex}
\title{Data on mortality of US men in 2002 by some causes}
\format{
\subsection{A dataframe}{

\describe{
\item{age}{age}
\item{neoplasms}{age specific mortality rate (asmr) from Neoplasms}
\item{circulatory}{asmr from Diseases of the circulatory system}
\item{respiratory}{asmr from Diseases of the respiratory system}
\item{digestive}{asmr from Diseases of the digestive system}
\item{other}{asmr from other causes}
\item{all}{overall asmr}
}
}
}
\source{
Andreev & Shkolnikov spreadsheet, can be seen on this \href{https://www.demogr.mpg.de/en/publications_databases_6118/publications_1904/mpidr_technical_reports/an_excel_spreadsheet_for_the_decomposition_of_a_difference_between_two_values_of_an_aggregate_demographic_4591}{webpage}
}
\usage{
asdtex
}
\description{
Data on mortality of US men in 2002 by some causes
}
\keyword{datasets}
